==> blesta-5.10.2.zip: blesta/plugins/domains/language/fr_fr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.change_auto_renewal'] = 'Le renouvellement automatique du domaine a été mis à jour !';
$lang['AdminMain.!success.domain_renewal'] = 'Le domaine a été renouvelé !';
$lang['AdminMain.!success.update_nameservers'] = 'Les serveurs de noms de domaine ont été mis à jour !';
$lang['AdminMain.!success.domains_pushed'] = 'Les domaines sélectionnés ont été transférés avec succès vers le nouveau client.';
$lang['AdminMain.index.page_title'] = 'Client #%1$s Domaines';
$lang['AdminMain.index.boxtitle_domains'] = 'Domaines';
$lang['AdminMain.index.heading_addons'] = 'Compléments';
$lang['AdminMain.index.heading_status'] = 'Statut';
$lang['AdminMain.index.heading_domain'] = 'Domaine';
$lang['AdminMain.index.heading_term'] = 'Durée';
$lang['AdminMain.index.heading_datecreated'] = 'Date de création';
$lang['AdminMain.index.heading_daterenews'] = 'Date Renouvellement';
$lang['AdminMain.index.heading_dateexpires'] = 'Date d\'expiration';
$lang['AdminMain.index.heading_datesuspended'] = 'Date de suspension';
$lang['AdminMain.index.heading_datecanceled'] = 'Date d\'annulation';
$lang['AdminMain.index.heading_options'] = 'Options';
$lang['AdminMain.index.category_active'] = 'Actif';
$lang['AdminMain.index.category_pending'] = 'En attente';
$lang['AdminMain.index.category_suspended'] = 'Suspendu';
$lang['AdminMain.index.category_canceled'] = 'Annulé';
$lang['AdminMain.index.categorylink_newservice'] = 'Nouveau domaine';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.option_parent'] = 'Parent';
$lang['AdminMain.index.option_manage'] = 'Gérer';
$lang['AdminMain.index.option_delete'] = 'Supprimer';
$lang['AdminMain.index.confirm_delete'] = 'Êtes-vous sûr de vouloir supprimer ce service ?';
$lang['AdminMain.index.no_results'] = 'Il n\'y a pas de services ayant ce statut.';
$lang['AdminMain.index.text_never'] = 'Jamais';
$lang['AdminMain.index.text_on'] = 'Sur';
$lang['AdminMain.index.text_off'] = 'Arrêt';
$lang['AdminMain.index.change_auto_renewal'] = 'Modifier le renouvellement de l\'assurance automobile';
$lang['AdminMain.index.domain_renewal'] = 'Renouveler le domaine';
$lang['AdminMain.index.update_nameservers'] = 'Mise à jour des serveurs de noms';
$lang['AdminMain.index.domain_push_to_client'] = 'Pousser vers le client';
$lang['AdminMain.index.field_actionsubmit'] = 'Soumettre';
$lang['AdminMain.domains.action.field_years'] = 'Années';
$lang['AdminMain.domains.action.field_nameservers'] = 'Serveurs de noms';
$lang['AdminMain.domains.action.field_client'] = 'Client';
$lang['AdminMain.getfilters.any'] = 'Tous';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nom de domaine';
$lang['AdminMain.!success.domains_unparented'] = 'Les domaines sélectionnés ont été retirés de leurs services parents et le prix a été réinitialisé avec succès !';
$lang['AdminMain.!success.domain_register'] = 'Le domaine a été enregistré avec succès !';
$lang['AdminMain.!success.domain_transfer'] = 'Le domaine a été transféré avec succès !';
$lang['AdminMain.!success.domain_add'] = 'Le domaine a été ajouté avec succès !';
$lang['AdminMain.!success.service_edited'] = 'Le domaine a été mis à jour avec succès !';
$lang['AdminMain.!error.unsupported_domain'] = 'Le nom de domaine n\'est pas pris en charge.';
$lang['AdminMain.index.unparent'] = 'Unparent et Reset Price';
$lang['AdminMain.add.boxtitle_client'] = 'Client #%1$s';
$lang['AdminMain.add.boxtitle_add'] = 'Ajouter un domaine : %1$s';
$lang['AdminMain.add.link_viewclient'] = 'Voir le client';
$lang['AdminMain.add.field_transfer'] = 'Transfert';
$lang['AdminMain.add.field_register'] = 'Registre';
$lang['AdminMain.add.field_add'] = 'Ajouter un domaine';
$lang['AdminMain.add.field_lookup'] = 'Vérifier la disponibilité';
$lang['AdminMain.add.field_submit'] = 'Continuer';
$lang['AdminMain.add.field_invoice_method'] = 'Méthode de facturation';
$lang['AdminMain.add.field_invoice_method_create'] = 'Créer une nouvelle facture';
$lang['AdminMain.add.field_invoice_method_append'] = 'Ajouter à une facture existante';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Ne pas facturer';
$lang['AdminMain.add.field_years'] = 'Années';
$lang['AdminMain.add.field_status'] = 'Statut';
$lang['AdminMain.add.field_module'] = 'Module du greffier';
$lang['AdminMain.add.field_use_module'] = 'Fournir le domaine à l\'aide du module d\'enregistrement lorsqu\'il est activé';
$lang['AdminMain.add.field_notify_order'] = 'Envoi d\'un courriel de confirmation de la commande lorsqu\'elle est activée';
$lang['AdminMain.add.title_search_results'] = 'Résultats de la recherche';
$lang['AdminMain.add.title_basic_options'] = 'Options de base';
$lang['AdminMain.add.title_registrar_options'] = 'Options du registraire';
$lang['AdminMain.add.heading_domain'] = 'Domaine';
$lang['AdminMain.add.heading_status'] = 'Statut';
$lang['AdminMain.add.heading_options'] = 'Options';
$lang['AdminMain.add.text_domain_available'] = 'Disponible';
$lang['AdminMain.add.text_domain_unavailable'] = 'Indisponible';
$lang['AdminMain.add.term_day'] = 'Jour %1$s';
$lang['AdminMain.add.term_days'] = '%1$s Days';
$lang['AdminMain.add.term_week'] = 'Semaine %1$s';
$lang['AdminMain.add.term_weeks'] = '%1$s Semaines';
$lang['AdminMain.add.term_month'] = '%1$s Mois';
$lang['AdminMain.add.term_months'] = '%1$s Mois';
$lang['AdminMain.add.term_year'] = '%1$s Année';
$lang['AdminMain.add.term_years'] = '%1$s Années';
$lang['AdminMain.add.order_btn'] = 'Commande sélectionnée';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (renouvellements @ %3$s)';
$lang['AdminMain.add.edit_package_pricing'] = 'Modifier la tarification';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Méthode de facturation :';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Créer une nouvelle facture';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Ajouter à la facture %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Ne pas facturer';
$lang['AdminMain.add_confirmation.field_status'] = 'Statut :';
$lang['AdminMain.add_confirmation.field_module'] = 'Module d\'enregistrement :';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Envoyer le courriel de confirmation de la commande :';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Oui';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Non';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domaine :';
$lang['AdminMain.add_confirmation.field_years'] = 'Années :';
$lang['AdminMain.add_confirmation.field_type'] = 'Type :';
$lang['AdminMain.add_confirmation.field_price'] = 'Prix :';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Code des coupons';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Mise à jour';
$lang['AdminMain.add_confirmation.field_add'] = 'Ajouter un domaine';
$lang['AdminMain.add_confirmation.field_edit'] = 'Editer';
$lang['AdminMain.add_confirmation.type_register'] = 'Inscription';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Transfert';
$lang['AdminMain.add_confirmation.description'] = 'Description';
$lang['AdminMain.add_confirmation.qty'] = 'Quantité';
$lang['AdminMain.add_confirmation.price'] = 'Prix';
$lang['AdminMain.add_confirmation.subtotal'] = 'Sous-total :';
$lang['AdminMain.add_confirmation.discount'] = 'Remise :';
$lang['AdminMain.edit.boxtitle_client'] = 'Client #%1$s';
$lang['AdminMain.edit.boxtitle_edit'] = 'Modifier le domaine : %1$s';
$lang['AdminMain.edit.link_viewclient'] = 'Voir le client';
$lang['AdminMain.edit.field_action'] = 'Action';
$lang['AdminMain.edit.field_years'] = 'Années';
$lang['AdminMain.edit.field_auto_renewal'] = 'Activer le renouvellement automatique';
$lang['AdminMain.edit.field_ns1'] = 'Serveur de noms 1';
$lang['AdminMain.edit.field_ns2'] = 'Serveur de noms 2';
$lang['AdminMain.edit.field_ns3'] = 'Serveur de noms 3';
$lang['AdminMain.edit.field_ns4'] = 'Serveur de noms 4';
$lang['AdminMain.edit.field_ns5'] = 'Serveur de noms 5';
$lang['AdminMain.edit.field_client'] = 'Client';
$lang['AdminMain.edit.field_module'] = 'Module du greffier';
$lang['AdminMain.edit.field_use_module'] = 'Module d\'utilisation';
$lang['AdminMain.edit.field_notify_order'] = 'Envoi d\'un courriel de confirmation de la commande lorsqu\'elle est activée';
$lang['AdminMain.edit.field_submit'] = 'Mise à jour';
$lang['AdminMain.edit.field_activate'] = 'Activer';
$lang['AdminMain.edit.field_edit_service'] = 'Service d\'édition';
$lang['AdminMain.edit.text_domain'] = 'Domaine :';
$lang['AdminMain.edit.text_registrar'] = 'Registrar :';
$lang['AdminMain.edit.text_years'] = 'Années d\'enregistrement :';
$lang['AdminMain.edit.text_status'] = 'Statut :';
$lang['AdminMain.edit.text_date_added'] = 'Date de création :';
$lang['AdminMain.edit.text_date_renews'] = 'Date de renouvellement :';
$lang['AdminMain.edit.text_date_expires'] = 'Date d\'expiration :';
$lang['AdminMain.edit.text_never'] = 'Jamais';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Date du dernier renouvellement :';
$lang['AdminMain.edit.text_date_suspended'] = 'Date de suspension :';
$lang['AdminMain.edit.text_date_canceled'] = 'Date d\'annulation :';
$lang['AdminMain.edit.term_day'] = 'Jour %1$s';
$lang['AdminMain.edit.term_days'] = '%1$s Days';
$lang['AdminMain.edit.term_week'] = 'Semaine %1$s';
$lang['AdminMain.edit.term_weeks'] = '%1$s Semaines';
$lang['AdminMain.edit.term_month'] = '%1$s Mois';
$lang['AdminMain.edit.term_months'] = '%1$s Mois';
$lang['AdminMain.edit.term_year'] = '%1$s Année';
$lang['AdminMain.edit.term_years'] = '%1$s Années';
$lang['AdminMain.edit.title_domain_information'] = 'Informations sur le domaine';
$lang['AdminMain.edit.title_actions'] = 'Actions';
$lang['AdminMain.edit.title_basic_options'] = 'Options de base';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Choisir Automatiquement --';
$lang['AdminMain.edit.text_registration_date'] = 'Date d\'enregistrement :';
$lang['AdminMain.index.text_date_added'] = 'Date d\'ajout :';
$lang['AdminMain.index.heading_dateregistration'] = 'Date d\'enregistrement';
$lang['AdminMain.index.heading_registrar'] = 'Greffier';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Le bureau d\'enregistrement du domaine a été mis à jour !';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/fr_fr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.change_auto_renewal'] = 'Le renouvellement automatique du domaine a été mis à jour !';
$lang['AdminMain.!success.domain_renewal'] = 'Le domaine a été renouvelé !';
$lang['AdminMain.!success.update_nameservers'] = 'Les serveurs de noms de domaine ont été mis à jour !';
$lang['AdminMain.!success.domains_pushed'] = 'Les domaines sélectionnés ont été transférés avec succès vers le nouveau client.';
$lang['AdminMain.index.page_title'] = 'Client #%1$s Domaines';
$lang['AdminMain.index.boxtitle_domains'] = 'Domaines';
$lang['AdminMain.index.heading_addons'] = 'Compléments';
$lang['AdminMain.index.heading_status'] = 'Statut';
$lang['AdminMain.index.heading_domain'] = 'Domaine';
$lang['AdminMain.index.heading_term'] = 'Durée';
$lang['AdminMain.index.heading_datecreated'] = 'Date de création';
$lang['AdminMain.index.heading_daterenews'] = 'Date Renouvellement';
$lang['AdminMain.index.heading_dateexpires'] = 'Date d\'expiration';
$lang['AdminMain.index.heading_datesuspended'] = 'Date de suspension';
$lang['AdminMain.index.heading_datecanceled'] = 'Date d\'annulation';
$lang['AdminMain.index.heading_options'] = 'Options';
$lang['AdminMain.index.category_active'] = 'Actif';
$lang['AdminMain.index.category_pending'] = 'En attente';
$lang['AdminMain.index.category_suspended'] = 'Suspendu';
$lang['AdminMain.index.category_canceled'] = 'Annulé';
$lang['AdminMain.index.categorylink_newservice'] = 'Nouveau domaine';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.option_parent'] = 'Parent';
$lang['AdminMain.index.option_manage'] = 'Gérer';
$lang['AdminMain.index.option_delete'] = 'Supprimer';
$lang['AdminMain.index.confirm_delete'] = 'Êtes-vous sûr de vouloir supprimer ce service ?';
$lang['AdminMain.index.no_results'] = 'Il n\'y a pas de services ayant ce statut.';
$lang['AdminMain.index.text_never'] = 'Jamais';
$lang['AdminMain.index.text_on'] = 'Sur';
$lang['AdminMain.index.text_off'] = 'Arrêt';
$lang['AdminMain.index.change_auto_renewal'] = 'Modifier le renouvellement de l\'assurance automobile';
$lang['AdminMain.index.domain_renewal'] = 'Renouveler le domaine';
$lang['AdminMain.index.update_nameservers'] = 'Mise à jour des serveurs de noms';
$lang['AdminMain.index.domain_push_to_client'] = 'Pousser vers le client';
$lang['AdminMain.index.field_actionsubmit'] = 'Soumettre';
$lang['AdminMain.domains.action.field_years'] = 'Années';
$lang['AdminMain.domains.action.field_nameservers'] = 'Serveurs de noms';
$lang['AdminMain.domains.action.field_client'] = 'Client';
$lang['AdminMain.getfilters.any'] = 'Tous';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nom de domaine';
$lang['AdminMain.!success.domains_unparented'] = 'Les domaines sélectionnés ont été retirés de leurs services parents et le prix a été réinitialisé avec succès !';
$lang['AdminMain.!success.domain_register'] = 'Le domaine a été enregistré avec succès !';
$lang['AdminMain.!success.domain_transfer'] = 'Le domaine a été transféré avec succès !';
$lang['AdminMain.!success.domain_add'] = 'Le domaine a été ajouté avec succès !';
$lang['AdminMain.!success.service_edited'] = 'Le domaine a été mis à jour avec succès !';
$lang['AdminMain.!error.unsupported_domain'] = 'Le nom de domaine n\'est pas pris en charge.';
$lang['AdminMain.index.unparent'] = 'Unparent et Reset Price';
$lang['AdminMain.add.boxtitle_client'] = 'Client #%1$s';
$lang['AdminMain.add.boxtitle_add'] = 'Ajouter un domaine : %1$s';
$lang['AdminMain.add.link_viewclient'] = 'Voir le client';
$lang['AdminMain.add.field_transfer'] = 'Transfert';
$lang['AdminMain.add.field_register'] = 'Registre';
$lang['AdminMain.add.field_add'] = 'Ajouter un domaine';
$lang['AdminMain.add.field_lookup'] = 'Vérifier la disponibilité';
$lang['AdminMain.add.field_submit'] = 'Continuer';
$lang['AdminMain.add.field_invoice_method'] = 'Méthode de facturation';
$lang['AdminMain.add.field_invoice_method_create'] = 'Créer une nouvelle facture';
$lang['AdminMain.add.field_invoice_method_append'] = 'Ajouter à une facture existante';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Ne pas facturer';
$lang['AdminMain.add.field_years'] = 'Années';
$lang['AdminMain.add.field_status'] = 'Statut';
$lang['AdminMain.add.field_module'] = 'Module du greffier';
$lang['AdminMain.add.field_use_module'] = 'Fournir le domaine à l\'aide du module d\'enregistrement lorsqu\'il est activé';
$lang['AdminMain.add.field_notify_order'] = 'Envoi d\'un courriel de confirmation de la commande lorsqu\'elle est activée';
$lang['AdminMain.add.title_search_results'] = 'Résultats de la recherche';
$lang['AdminMain.add.title_basic_options'] = 'Options de base';
$lang['AdminMain.add.title_registrar_options'] = 'Options du registraire';
$lang['AdminMain.add.heading_domain'] = 'Domaine';
$lang['AdminMain.add.heading_status'] = 'Statut';
$lang['AdminMain.add.heading_options'] = 'Options';
$lang['AdminMain.add.text_domain_available'] = 'Disponible';
$lang['AdminMain.add.text_domain_unavailable'] = 'Indisponible';
$lang['AdminMain.add.term_day'] = 'Jour %1$s';
$lang['AdminMain.add.term_days'] = '%1$s Days';
$lang['AdminMain.add.term_week'] = 'Semaine %1$s';
$lang['AdminMain.add.term_weeks'] = '%1$s Semaines';
$lang['AdminMain.add.term_month'] = '%1$s Mois';
$lang['AdminMain.add.term_months'] = '%1$s Mois';
$lang['AdminMain.add.term_year'] = '%1$s Année';
$lang['AdminMain.add.term_years'] = '%1$s Années';
$lang['AdminMain.add.order_btn'] = 'Commande sélectionnée';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (renouvellements @ %3$s)';
$lang['AdminMain.add.edit_package_pricing'] = 'Modifier la tarification';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Méthode de facturation :';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Créer une nouvelle facture';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Ajouter à la facture %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Ne pas facturer';
$lang['AdminMain.add_confirmation.field_status'] = 'Statut :';
$lang['AdminMain.add_confirmation.field_module'] = 'Module d\'enregistrement :';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Envoyer le courriel de confirmation de la commande :';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Oui';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Non';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domaine :';
$lang['AdminMain.add_confirmation.field_years'] = 'Années :';
$lang['AdminMain.add_confirmation.field_type'] = 'Type :';
$lang['AdminMain.add_confirmation.field_price'] = 'Prix :';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Code des coupons';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Mise à jour';
$lang['AdminMain.add_confirmation.field_add'] = 'Ajouter un domaine';
$lang['AdminMain.add_confirmation.field_edit'] = 'Editer';
$lang['AdminMain.add_confirmation.type_register'] = 'Inscription';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Transfert';
$lang['AdminMain.add_confirmation.description'] = 'Description';
$lang['AdminMain.add_confirmation.qty'] = 'Quantité';
$lang['AdminMain.add_confirmation.price'] = 'Prix';
$lang['AdminMain.add_confirmation.subtotal'] = 'Sous-total :';
$lang['AdminMain.add_confirmation.discount'] = 'Remise :';
$lang['AdminMain.edit.boxtitle_client'] = 'Client #%1$s';
$lang['AdminMain.edit.boxtitle_edit'] = 'Modifier le domaine : %1$s';
$lang['AdminMain.edit.link_viewclient'] = 'Voir le client';
$lang['AdminMain.edit.field_action'] = 'Action';
$lang['AdminMain.edit.field_years'] = 'Années';
$lang['AdminMain.edit.field_auto_renewal'] = 'Activer le renouvellement automatique';
$lang['AdminMain.edit.field_ns1'] = 'Serveur de noms 1';
$lang['AdminMain.edit.field_ns2'] = 'Serveur de noms 2';
$lang['AdminMain.edit.field_ns3'] = 'Serveur de noms 3';
$lang['AdminMain.edit.field_ns4'] = 'Serveur de noms 4';
$lang['AdminMain.edit.field_ns5'] = 'Serveur de noms 5';
$lang['AdminMain.edit.field_client'] = 'Client';
$lang['AdminMain.edit.field_module'] = 'Module du greffier';
$lang['AdminMain.edit.field_use_module'] = 'Module d\'utilisation';
$lang['AdminMain.edit.field_notify_order'] = 'Envoi d\'un courriel de confirmation de la commande lorsqu\'elle est activée';
$lang['AdminMain.edit.field_submit'] = 'Mise à jour';
$lang['AdminMain.edit.field_activate'] = 'Activer';
$lang['AdminMain.edit.field_edit_service'] = 'Service d\'édition';
$lang['AdminMain.edit.text_domain'] = 'Domaine :';
$lang['AdminMain.edit.text_registrar'] = 'Registrar :';
$lang['AdminMain.edit.text_years'] = 'Années d\'enregistrement :';
$lang['AdminMain.edit.text_status'] = 'Statut :';
$lang['AdminMain.edit.text_date_added'] = 'Date de création :';
$lang['AdminMain.edit.text_date_renews'] = 'Date de renouvellement :';
$lang['AdminMain.edit.text_date_expires'] = 'Date d\'expiration :';
$lang['AdminMain.edit.text_never'] = 'Jamais';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Date du dernier renouvellement :';
$lang['AdminMain.edit.text_date_suspended'] = 'Date de suspension :';
$lang['AdminMain.edit.text_date_canceled'] = 'Date d\'annulation :';
$lang['AdminMain.edit.term_day'] = 'Jour %1$s';
$lang['AdminMain.edit.term_days'] = '%1$s Days';
$lang['AdminMain.edit.term_week'] = 'Semaine %1$s';
$lang['AdminMain.edit.term_weeks'] = '%1$s Semaines';
$lang['AdminMain.edit.term_month'] = '%1$s Mois';
$lang['AdminMain.edit.term_months'] = '%1$s Mois';
$lang['AdminMain.edit.term_year'] = '%1$s Année';
$lang['AdminMain.edit.term_years'] = '%1$s Années';
$lang['AdminMain.edit.title_domain_information'] = 'Informations sur le domaine';
$lang['AdminMain.edit.title_actions'] = 'Actions';
$lang['AdminMain.edit.title_basic_options'] = 'Options de base';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Choisir Automatiquement --';
$lang['AdminMain.edit.text_registration_date'] = 'Date d\'enregistrement :';
$lang['AdminMain.index.text_date_added'] = 'Date d\'ajout :';
$lang['AdminMain.index.heading_dateregistration'] = 'Date d\'enregistrement';
$lang['AdminMain.index.heading_registrar'] = 'Greffier';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Le bureau d\'enregistrement du domaine a été mis à jour !';
$lang['AdminMain.edit.field_registration_date'] = 'Modifier la date d\'inscription';
$lang['AdminMain.edit.field_expiration_date'] = 'Modifier la date d\'expiration';
$lang['AdminMain.!success.change_registration_date'] = 'La date d\'enregistrement du domaine a été mise à jour !';
$lang['AdminMain.!success.change_expiration_date'] = 'La date d\'expiration du domaine a été mise à jour !';
